@@ -1,10 +1,12 @@
 ### FUNCTION TO FIT VENN DIAGRAM TO SIZE ##########################################################
 adjust.venn <- function(gList1, margin = 0.01, ...) {
+
 	x.vect <- vector();
 	y.vect <- vector();
 	
 	x.list <- list();
 	y.list <- list();
+
 	for (i in 1:length(gList1)) {
 		
 		x.vect <- c(x.vect, as.vector(gList1[i][[1]]$x, mode = "numeric"));
@@ -23,32 +25,26 @@ adjust.venn <- function(gList1, margin = 0.01, ...) {
 	y.centre <- (max.y + min.y) / 2;
 		
 	size <- 0.99;
+
 	if (max.x - min.x >= max.y - min.y) {
-		
 		for (i in 1:length(x.list)) {
 			x.list[[i]] <- unit((x.list[[i]] - x.centre) * (size / (max.x - min.x)) + 0.5, "npc");
 			y.list[[i]] <- unit((y.list[[i]] - y.centre) * (size / (max.x - min.x)) + 0.5, "npc");
-			
 			}
-		
 		}
 		
 	if (max.x - min.x < max.y - min.y) {
-		
 		for (i in 1:length(x.list)) {
 			x.list[[i]] <- unit((x.list[[i]] - x.centre) * (size / (max.y - min.y)) + 0.5, "npc");
 			y.list[[i]] <- unit((y.list[[i]] - y.centre) * (size / (max.y - min.y)) + 0.5, "npc");
 			}
-		
 		}
 		
 	for (i in 1:length(gList1)) {
-	
 		gList1[i][[1]]$x <- x.list[[i]];
 		gList1[i][[1]]$y <- y.list[[i]];
-		
 		}
 		
-	return(gList1)
+	return(gList1);
 		
 	}
