@@ -1,48 +1,48 @@
 ### FUNCTION TO DRAW VENN DIAGRAM WITH TWO SETS ###################################################
-draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2), cat.default.pos = "outer", euler.d = TRUE, scaled = TRUE, inverted = FALSE, ext.text = TRUE, ext.pos = rep(0, 2), ext.dist = rep(0, 2), ext.line.lty = "solid", ext.l = rep(0.95, 2), lwd = rep(2, 2), lty = rep("solid", 2), col = rep("black", 2), label.col = rep("black", 3), cex = rep(1, 3), fontface = rep("plain", 3), fontfamily = rep("serif", 3), cat.pos = c(-50, 50), cat.dist = rep(0.025, 2), cat.col = rep("black", 2), cat.cex = rep(1, 2), cat.fontface = rep("plain", 2), cat.fontfamily = rep("serif", 2), cat.just = rep(list(c(0.5, 0.5)), 2), cat.prompts = FALSE, fill = NULL, alpha = rep(0.5, 2), rotation.degree = 0, rotation.centre = c(0.5, 0.5), ext.line.lwd = 1, ind = TRUE, sep.dist = 0.05, offset = 0, ...) {
+draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2), cat.default.pos = "outer", euler.d = TRUE, scaled = TRUE, inverted = FALSE, ext.text = TRUE, ext.pos = rep(0, 2), ext.dist = rep(0, 2), ext.line.lty = "solid", ext.length = rep(0.95, 2), lwd = rep(2, 2), lty = rep("solid", 2), col = rep("black", 2), label.col = rep("black", 3), cex = rep(1, 3), fontface = rep("plain", 3), fontfamily = rep("serif", 3), cat.pos = c(-50, 50), cat.dist = rep(0.025, 2), cat.col = rep("black", 2), cat.cex = rep(1, 2), cat.fontface = rep("plain", 2), cat.fontfamily = rep("serif", 2), cat.just = rep(list(c(0.5, 0.5)), 2), cat.prompts = FALSE, fill = NULL, alpha = rep(0.5, 2), rotation.degree = 0, rotation.centre = c(0.5, 0.5), ext.line.lwd = 1, ind = TRUE, sep.dist = 0.05, offset = 0, ...) {
 	# area1 > area2 OR area1 < area2 plots the same Venn diagram.  Invert using the "inverted" argument.
 	# check parameter lengths and plausibility of Venn diagram
-	if (length(category) == 1) {category = rep(category, 2)}
-	if (length(category) != 1 & length(category) != 2) { stop("Unexpected parameter length for 'category'.") }
-	if (length(ext.pos) == 1) {ext.pos = rep(ext.pos, 2)}
-	if (length(ext.pos) != 1 & length(ext.pos) != 2) { stop("Unexpected parameter length for 'ext.pos'.") }
-	if (length(ext.dist) == 1) {ext.dist = rep(ext.dist, 2)}
-	if (length(ext.dist) != 1 & length(ext.dist) != 2) { stop("Unexpected parameter length for 'ext.dist'.") }
-	if (length(ext.l) == 1) {ext.l = rep(ext.l, 2)}
-	if (length(ext.l) != 1 & length(ext.l) != 2) { stop("Unexpected parameter length for 'ext.l'.") }
-	if (length(lwd) == 1) {lwd = rep(lwd, 2)}
-	if (length(lwd) != 1 & length(lwd) != 2) { stop("Unexpected parameter length for 'lwd'.") }
-	if (length(lty) == 1) {lty = rep(lty, 2)}
-	if (length(lty) != 1 & length(lty) != 2) { stop("Unexpected parameter length for 'lty'.") }
-	if (length(col) == 1) {col = rep(col, 2)}
-	if (length(col) != 1 & length(col) != 2) { stop("Unexpected parameter length for 'col'.") }
-	if (length(label.col) == 1) {label.col = rep(label.col, 3)}
-	if (length(label.col) != 1 & length(label.col) != 3) { stop("Unexpected parameter length for 'label.col'.") }
-	if (length(cex) == 1) {cex = rep(cex, 3)}
-	if (length(cex) != 1 & length(cex) != 3) { stop("Unexpected parameter length for 'cex'.") }
-	if (length(fontface) == 1) {fontface = rep(fontface, 3)}
-	if (length(fontface) != 1 & length(fontface) != 3) { stop("Unexpected parameter length for 'fontface'.") }
-	if (length(fontfamily) == 1) {fontfamily = rep(fontfamily, 3)}
-	if (length(fontfamily) != 1 & length(fontfamily) != 3) { stop("Unexpected parameter length for 'fontfamily'.") }
-	if (length(fill) == 1) {fill = rep(fill, 2)}
-	if (length(fill) != 1 & length(fill) != 2 & length(fill) != 0) { stop("Unexpected parameter length for 'fill'.") }
-	if (length(alpha) == 1) {alpha = rep(alpha, 2)}
-	if (length(alpha) != 1 & length(alpha) != 2 & length(alpha) != 0) { stop("Unexpected parameter length for 'alpha'.") }
-	if (length(ext.line.lwd) != 1) { stop("Unexpected parameter length for 'ext.line.lwd'.") }
-	if (length(cat.pos) == 1) {cat.pos = rep(cat.pos, 2)}
-	if (length(cat.pos) != 1 & length(cat.pos) != 2 ) { stop("Unexpected parameter length for 'cat.pos'.") }
-	if (length(cat.dist) == 1) {cat.dist = rep(cat.dist, 2)}
-	if (length(cat.dist) != 1 & length(cat.dist) != 2) { stop("Unexpected parameter length for 'cat.dist'.") }
-	if (length(cat.col) == 1) {cat.col = rep(cat.col, 2)}
-	if (length(cat.col) != 1 & length(cat.col) != 2) { stop("Unexpected parameter length for 'cat.col'.") }
-	if (length(cat.cex) == 1) {cat.cex = rep(cat.cex, 2)}
-	if (length(cat.cex) != 1 & length(cat.cex) != 2) { stop("Unexpected parameter length for 'cat.cex'.") }
-	if (length(cat.fontface) == 1) {cat.fontface = rep(cat.fontface, 2)}
-	if (length(cat.fontface) != 1 & length(cat.fontface) != 2) { stop("Unexpected parameter length for 'cat.fontface'.") }
-	if (length(cat.fontfamily) == 1) {cat.fontfamily = rep(cat.fontfamily, 2)}
-	if (length(cat.fontfamily) != 1 & length(cat.fontfamily) != 2) { stop("Unexpected parameter length for 'cat.fontfamily'.") }
-	if (length(offset) != 1) { stop("Unexpected parameter length for 'cat.fontfamily'. Try using 'rotation.degree' to achieve non-vertical offsets.") }
-	if (!(class(cat.just) == "list" & length(cat.just) == 2 & length(cat.just[[1]]) == 2 & length(cat.just[[2]]) == 2)) { stop("Unexpected parameter format for 'cat.just'.") }
+	if (length(category) == 1) {category <- rep(category, 2)}
+	if (length(category) != 1 & length(category) != 2) { stop("Unexpected parameter length for 'category'") }
+	if (length(ext.pos) == 1) {ext.pos <- rep(ext.pos, 2)}
+	if (length(ext.pos) != 1 & length(ext.pos) != 2) { stop("Unexpected parameter length for 'ext.pos'") }
+	if (length(ext.dist) == 1) {ext.dist <- rep(ext.dist, 2)}
+	if (length(ext.dist) != 1 & length(ext.dist) != 2) { stop("Unexpected parameter length for 'ext.dist'") }
+	if (length(ext.length) == 1) {ext.length <- rep(ext.length, 2)}
+	if (length(ext.length) != 1 & length(ext.length) != 2) { stop("Unexpected parameter length for 'ext.length'") }
+	if (length(lwd) == 1) {lwd <- rep(lwd, 2)}
+	if (length(lwd) != 1 & length(lwd) != 2) { stop("Unexpected parameter length for 'lwd'") }
+	if (length(lty) == 1) {lty <- rep(lty, 2)}
+	if (length(lty) != 1 & length(lty) != 2) { stop("Unexpected parameter length for 'lty'") }
+	if (length(col) == 1) {col <- rep(col, 2)}
+	if (length(col) != 1 & length(col) != 2) { stop("Unexpected parameter length for 'col'") }
+	if (length(label.col) == 1) {label.col <- rep(label.col, 3)}
+	if (length(label.col) != 1 & length(label.col) != 3) { stop("Unexpected parameter length for 'label.col'") }
+	if (length(cex) == 1) {cex <- rep(cex, 3)}
+	if (length(cex) != 1 & length(cex) != 3) { stop("Unexpected parameter length for 'cex'") }
+	if (length(fontface) == 1) {fontface <- rep(fontface, 3)}
+	if (length(fontface) != 1 & length(fontface) != 3) { stop("Unexpected parameter length for 'fontface'") }
+	if (length(fontfamily) == 1) {fontfamily <- rep(fontfamily, 3)}
+	if (length(fontfamily) != 1 & length(fontfamily) != 3) { stop("Unexpected parameter length for 'fontfamily'") }
+	if (length(fill) == 1) {fill <- rep(fill, 2)}
+	if (length(fill) != 1 & length(fill) != 2 & length(fill) != 0) { stop("Unexpected parameter length for 'fill'") }
+	if (length(alpha) == 1) {alpha <- rep(alpha, 2)}
+	if (length(alpha) != 1 & length(alpha) != 2 & length(alpha) != 0) { stop("Unexpected parameter length for 'alpha'") }
+	if (length(ext.line.lwd) != 1) { stop("Unexpected parameter length for 'ext.line.lwd'") }
+	if (length(cat.pos) == 1) {cat.pos <- rep(cat.pos, 2)}
+	if (length(cat.pos) != 1 & length(cat.pos) != 2 ) { stop("Unexpected parameter length for 'cat.pos'") }
+	if (length(cat.dist) == 1) {cat.dist <- rep(cat.dist, 2)}
+	if (length(cat.dist) != 1 & length(cat.dist) != 2) { stop("Unexpected parameter length for 'cat.dist'") }
+	if (length(cat.col) == 1) {cat.col <- rep(cat.col, 2)}
+	if (length(cat.col) != 1 & length(cat.col) != 2) { stop("Unexpected parameter length for 'cat.col'") }
+	if (length(cat.cex) == 1) {cat.cex <- rep(cat.cex, 2)}
+	if (length(cat.cex) != 1 & length(cat.cex) != 2) { stop("Unexpected parameter length for 'cat.cex'") }
+	if (length(cat.fontface) == 1) {cat.fontface <- rep(cat.fontface, 2)}
+	if (length(cat.fontface) != 1 & length(cat.fontface) != 2) { stop("Unexpected parameter length for 'cat.fontface'") }
+	if (length(cat.fontfamily) == 1) {cat.fontfamily <- rep(cat.fontfamily, 2)}
+	if (length(cat.fontfamily) != 1 & length(cat.fontfamily) != 2) { stop("Unexpected parameter length for 'cat.fontfamily'") }
+	if (length(offset) != 1) { stop("Unexpected parameter length for 'cat.fontfamily'. Try using 'rotation.degree' to achieve non-vertical offsets") }
+	if (!(class(cat.just) == "list" & length(cat.just) == 2 & length(cat.just[[1]]) == 2 & length(cat.just[[2]]) == 2)) { stop("Unexpected parameter format for 'cat.just'") }
 	
 	# check uninterpretable parameters
 	if (euler.d == FALSE & scaled == TRUE) {
@@ -84,46 +84,48 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 		tmp2 <- min(area1, area2);
 		area1 <- tmp1;
 		area2 <- tmp2;
-		r1 = sqrt(area1 / pi);
-		r2 = sqrt(area2 / pi);
+		r1 <- sqrt(area1 / pi);
+		r2 <- sqrt(area2 / pi);
 		shrink.factor <- max.circle.size / r1;
 		}
-	if (inverted == TRUE) {
+	else {
 		tmp1 <- min(area1, area2);
 		tmp2 <- max(area1, area2);
 		area1 <- tmp1;
 		area2 <- tmp2;
 		category <- rev(category);
 		
-		r1 = sqrt(area1 / pi);
-		r2 = sqrt(area2 / pi);
+		r1 <- sqrt(area1 / pi);
+		r2 <- sqrt(area2 / pi);
 		shrink.factor <- max.circle.size / r2;
 		
-		ext.pos = rev(ext.pos);
-		ext.dist = rev(ext.dist);
-		lwd = rev(lwd);
-		lty = rev(lty);
-		col = rev(col);
-		label.col = rev(label.col);
-		cex = rev(cex);
-		fontface = rev(fontface);
-		fontfamily = rev(fontfamily);
-		cat.dist = rev(cat.dist);
-		cat.col = rev(cat.col);
-		cat.cex = rev(cat.cex);
-		cat.fontface = rev(cat.fontface);
-		cat.fontfamily = rev(cat.fontfamily);
-		fill = rev(fill);
-		alpha = rev(alpha);
+		ext.pos <- rev(ext.pos);
+		ext.dist <- rev(ext.dist);
+		lwd <- rev(lwd);
+		lty <- rev(lty);
+		col <- rev(col);
+		label.col <- rev(label.col);
+		cex <- rev(cex);
+		fontface <- rev(fontface);
+		fontfamily <- rev(fontfamily);
+		cat.dist <- rev(cat.dist);
+		cat.col <- rev(cat.col);
+		cat.cex <- rev(cat.cex);
+		cat.fontface <- rev(cat.fontface);
+		cat.fontfamily <- rev(cat.fontfamily);
+		fill <- rev(fill);
+		alpha <- rev(alpha);
 		}	
 		
 	# convert radii to Grid dimensions
 	r1 <- r1 * shrink.factor;
 	r2 <- r2 * shrink.factor;
+
 	# check special conditions
-	if (area1 == area2 & area2 == cross.area) { special.coincidental <- TRUE }		
-	if (cross.area == area2 | cross.area == area1) { special.inclusion <- TRUE }
-	if (cross.area == 0) { special.exclusion <- TRUE }
+	if (area1 == area2 & area2 == cross.area) { special.coincidental <- TRUE; }
+	if (cross.area == area2 | cross.area == area1) { special.inclusion <- TRUE; }
+	if (cross.area == 0) { special.exclusion <- TRUE; }
+
 	# plot scaled, generic pairwise Venn diagram with or without external texts
 	if (scaled & !special.inclusion & !special.exclusion & !special.coincidental) {
 		d <- find.dist(area1, area2, cross.area, inverted = inverted);
@@ -142,6 +144,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- circle(
 			x = x.centre.2, 
 			y = 0.5, 
@@ -153,6 +156,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			); 
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- circle(
 			x = x.centre.1, 
 			y = 0.5, 
@@ -165,6 +169,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- circle(
 			x = x.centre.2, 
 			y = 0.5, 
@@ -212,8 +217,8 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 					);
 				grob.list <- gList(grob.list, tmp);
 				tmp <- linesGrob(
-					x = c(area.1.pos + ext.l[1] * (area.1.xpos - area.1.pos), area.1.pos), 
-					y = c(0.5 + ext.l[1] * (area.1.ypos - 0.5), 0.5),
+					x = c(area.1.pos + ext.length[1] * (area.1.xpos - area.1.pos), area.1.pos), 
+					y = c(0.5 + ext.length[1] * (area.1.ypos - 0.5), 0.5),
 					gp = gpar(
 						col = label.col[1],
 						lwd = ext.line.lwd,
@@ -255,8 +260,8 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 					);
 				grob.list <- gList(grob.list, tmp);
 				tmp <- linesGrob(
-					x = c(area.2.pos + ext.l[1] * (area.2.xpos - area.2.pos), area.2.pos), 
-					y = c(0.5 + ext.l[1] * (area.2.ypos - 0.5), 0.5), 
+					x = c(area.2.pos + ext.length[1] * (area.2.xpos - area.2.pos), area.2.pos), 
+					y = c(0.5 + ext.length[1] * (area.2.ypos - 0.5), 0.5), 
 					gp = gpar(
 						col = label.col[3],
 						lwd = ext.line.lwd,
@@ -297,8 +302,8 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 					);
 				grob.list <- gList(grob.list, tmp);
 				tmp <- linesGrob(
-					x = c(cross.area.pos + ext.l[2] * (cross.area.xpos - cross.area.pos), cross.area.pos), 
-					y = c(0.5 + ext.l[2] * (cross.area.ypos - 0.5), 0.5), 
+					x = c(cross.area.pos + ext.length[2] * (cross.area.xpos - cross.area.pos), cross.area.pos), 
+					y = c(0.5 + ext.length[2] * (cross.area.ypos - 0.5), 0.5), 
 					gp = gpar(
 						col = label.col[1],
 						lwd = ext.line.lwd,
@@ -348,9 +353,20 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				);
 			grob.list <- gList(grob.list, tmp);
 			}	
-			
-		if (cat.default.pos == "outer") { cat.pos.1 <- find.cat.pos(x.centre.1, 0.5, cat.pos[1], cat.dist[1], r1) }
-		if (cat.default.pos == "text") { cat.pos.1 <- find.cat.pos(area.1.pos, 0.5, cat.pos[1], cat.dist[1]) }
+
+		# find the location of the category labels
+		if (cat.default.pos == "outer") {
+			cat.pos.1 <- find.cat.pos(x.centre.1, 0.5, cat.pos[1], cat.dist[1], r1);
+			cat.pos.2 <- find.cat.pos(x.centre.2, 0.5, cat.pos[2], cat.dist[2], r2);
+			}
+		else if (cat.default.pos == "text") {
+			cat.pos.1 <- find.cat.pos(area.1.pos, 0.5, cat.pos[1], cat.dist[1]);
+			cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]);
+			}
+		else {
+			stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
+			}
+
 		tmp <- textGrob(
 			label = category[1],
 			x = cat.pos.1$x,
@@ -365,8 +381,6 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 			);
 		grob.list <- gList(grob.list, tmp);
 		
-		if (cat.default.pos == "outer") { cat.pos.2 <- find.cat.pos(x.centre.2, 0.5, cat.pos[2], cat.dist[2], r2) }
-		if (cat.default.pos == "text") { cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]) }
 		tmp <- textGrob(
 			label = category[2],
 			x = cat.pos.2$x,
@@ -382,6 +396,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 		grob.list <- gList(grob.list, tmp);
 	
 		}
+	
 	# plot scaled Venn diagram when one set is completely included in (but not exactly coincidental with) the other set 
 	# with or without external texts
 	if (euler.d & special.inclusion & !special.coincidental) {
@@ -414,6 +429,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- circle(
 			x = 0.5 - offset * (r1 - r2), 
 			y = 0.5, 
@@ -425,6 +441,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- circle(
 			x = 0.5, 
 			y = 0.5, 
@@ -437,6 +454,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- circle(
 			x = 0.5 - offset * (r1 - r2), 
 			y = 0.5, 
@@ -449,6 +467,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		area.2.pos <- 0.5 - offset * (r1 - r2);
 		tmp <- textGrob(
 			label = area2, 
@@ -462,6 +481,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		if (!ext.text | !scaled) {
 			area.1.pos <- (1 + r1 + r2 - offset * (r1 - r2)) / 2;
 			tmp <- textGrob(
@@ -477,6 +497,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				);
 			grob.list <- gList(grob.list, tmp);
 			}
+
 		if (ext.text & scaled) {
 			if (area2 / area1 > 0.5) {
 				area.1.pos <- (1 + r1 + r2 - offset * (r1 - r2)) / 2;
@@ -496,8 +517,8 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 					);
 				grob.list <- gList(grob.list, tmp);
 				tmp <- linesGrob(
-					x = c(area.1.pos + ext.l * (area.1.xpos - area.1.pos), area.1.pos), 
-					y = c(0.5 + ext.l * (area.1.ypos - 0.5), 0.5),
+					x = c(area.1.pos + ext.length * (area.1.xpos - area.1.pos), area.1.pos), 
+					y = c(0.5 + ext.length * (area.1.ypos - 0.5), 0.5),
 					gp = gpar(
 						col = label.col[1],
 						lwd = ext.line.lwd,
@@ -523,8 +544,18 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				}
 			}
 		
-		if (cat.default.pos == "outer") { cat.pos.1 <- find.cat.pos(0.5, 0.5, cat.pos[1], cat.dist[1], r1) }
-		if (cat.default.pos == "text") { cat.pos.1 <- find.cat.pos(area.1.pos, 0.5, cat.pos[1], cat.dist[1]) }
+		if (cat.default.pos == "outer") {
+			cat.pos.1 <- find.cat.pos(0.5, 0.5, cat.pos[1], cat.dist[1], r1);
+			cat.pos.2 <- find.cat.pos(0.5 - offset * (r1 - r2), 0.5, cat.pos[2], cat.dist[2], r2);
+			}
+		else if (cat.default.pos == "text") {
+			cat.pos.1 <- find.cat.pos(area.1.pos, 0.5, cat.pos[1], cat.dist[1]);
+			cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]);
+			}
+		else {
+			stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
+			}
+
 		tmp <- textGrob(
 			label = category[1],
 			x = cat.pos.1$x,
@@ -538,9 +569,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
-		
-		if (cat.default.pos == "outer") { cat.pos.2 <- find.cat.pos(0.5 - offset * (r1 - r2), 0.5, cat.pos[2], cat.dist[2], r2) }
-		if (cat.default.pos == "text") { cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]) }
+
 		tmp <- textGrob(
 			label = category[2],
 			x = cat.pos.2$x,
@@ -556,8 +585,10 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 		grob.list <- gList(grob.list, tmp);
 	
 		}
+
 	# plot scaled Venn diagrams when the two sets are coincidental
 	if (euler.d & special.coincidental) {
+
 		tmp <- circle(
 			x = 0.5, 
 			y = 0.5, 
@@ -569,6 +600,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- circle(
 			x = 0.5, 
 			y = 0.5, 
@@ -581,6 +613,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		area.1.pos <- 0.46;
 		tmp <- textGrob(
 			label = area1, 
@@ -594,7 +627,8 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
-		area.2.pos <- 0.54
+
+		area.2.pos <- 0.54;
 		tmp <- textGrob(
 			label = area2, 
 			x = area.2.pos, 
@@ -607,6 +641,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- textGrob(
 			label = "(Coincidental)", 
 			x = 0.5, 
@@ -620,8 +655,18 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 			);
 		grob.list <- gList(grob.list, tmp);
 		
-		if (cat.default.pos == "outer") { cat.pos.1 <- find.cat.pos(0.5, 0.5, cat.pos[1], cat.dist[1], max.circle.size) }
-		if (cat.default.pos == "text") { cat.pos.1 <- find.cat.pos(area.1.pos, 0.5, cat.pos[1], cat.dist[1]) }
+		if (cat.default.pos == "outer") {
+			cat.pos.1 <- find.cat.pos(0.5, 0.5, cat.pos[1], cat.dist[1], max.circle.size);
+			cat.pos.2 <- find.cat.pos(0.5, 0.5, cat.pos[2], cat.dist[2], max.circle.size);
+			}
+		else if (cat.default.pos == "text") {
+			cat.pos.1 <- find.cat.pos(area.1.pos, 0.5, cat.pos[1], cat.dist[1]);
+			cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]);
+			}
+		else {
+			stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
+			}
+
 		tmp <- textGrob(
 			label = category[1],
 			x = cat.pos.1$x,
@@ -636,8 +681,6 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 			);
 		grob.list <- gList(grob.list, tmp);
 		
-		if (cat.default.pos == "outer") { cat.pos.2 <- find.cat.pos(0.5, 0.5, cat.pos[2], cat.dist[2], max.circle.size) }
-		if (cat.default.pos == "text") { cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]) }
 		tmp <- textGrob(
 			label = category[2],
 			x = cat.pos.2$x,
@@ -653,6 +696,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 		grob.list <- gList(grob.list, tmp);
 	
 		}
+
 	# plot scaled Venn diagrams when the two sets are mutually exclusive
 	if (euler.d & special.exclusion) {
 	
@@ -673,6 +717,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		x.centre.2 <- r1 + (1 + sep.dist) * (r1 + r2);
 		tmp <- circle(
 			x = x.centre.2, 
@@ -685,6 +730,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- circle(
 			x = x.centre.1, 
 			y = 0.5, 
@@ -697,6 +743,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- circle(
 			x = x.centre.2, 
 			y = 0.5, 
@@ -709,6 +756,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		area.1.pos <- x.centre.1;
 		tmp <- textGrob(
 			label = area1, 
@@ -722,6 +770,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		area.2.pos <- x.centre.2;
 		tmp <- textGrob(
 			label = area2, 
@@ -736,8 +785,18 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 			);
 		grob.list <- gList(grob.list, tmp);
 		
-		if (cat.default.pos == "outer") { cat.pos.1 <- find.cat.pos(x.centre.1, 0.5, cat.pos[1], cat.dist[1], r1) }
-		if (cat.default.pos == "text") { cat.pos.1 <- find.cat.pos(area.1.pos, 0.5, cat.pos[1], cat.dist[1]) }
+		if (cat.default.pos == "outer") {
+			cat.pos.1 <- find.cat.pos(x.centre.1, 0.5, cat.pos[1], cat.dist[1], r1);
+			cat.pos.2 <- find.cat.pos(x.centre.2, 0.5, cat.pos[2], cat.dist[2], r2);
+			}
+		else if (cat.default.pos == "text") {
+			cat.pos.1 <- find.cat.pos(area.1.pos, 0.5, cat.pos[1], cat.dist[1]);
+			cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]);
+			}
+		else {
+			stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
+			}
+
 		tmp <- textGrob(
 			label = category[1],
 			x = cat.pos.1$x,
@@ -751,8 +810,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
-		if (cat.default.pos == "outer") { cat.pos.2 <- find.cat.pos(x.centre.2, 0.5, cat.pos[2], cat.dist[2], r2) }
-		if (cat.default.pos == "text") { cat.pos.2 <- find.cat.pos(area.2.pos, 0.5, cat.pos[2], cat.dist[2]) }
+
 		tmp <- textGrob(
 			label = category[2],
 			x = cat.pos.2$x,
@@ -768,8 +826,10 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 		grob.list <- gList(grob.list, tmp);
 	
 		}
+
 	# plot non-scaled Venn diagram
 	if ((!scaled & !euler.d) | (!scaled & euler.d & !special.inclusion & !special.exclusion & !special.coincidental)) {
+
 		tmp <- circle(
 			x = 0.4, 
 			y = 0.5, 
@@ -781,6 +841,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- circle(
 			x = 0.6, 
 			y = 0.5, 
@@ -792,6 +853,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- circle(
 			x = 0.4, 
 			y = 0.5, 
@@ -804,6 +866,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- circle(
 			x = 0.6, 
 			y = 0.5, 
@@ -816,6 +879,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- textGrob(
 			label = area1 - cross.area, 
 			x = 0.3, 
@@ -828,6 +892,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- textGrob(
 			label = area2 - cross.area, 
 			x = 0.7, 
@@ -840,6 +905,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 				)
 			);
 		grob.list <- gList(grob.list, tmp);
+
 		tmp <- textGrob(
 			label = cross.area, 
 			x = 0.5, 
@@ -853,8 +919,18 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 			);
 		grob.list <- gList(grob.list, tmp);
 		
-		if (cat.default.pos == "outer") { cat.pos.1 <- find.cat.pos(0.4, 0.5, cat.pos[1], cat.dist[1], max.circle.size) }
-		if (cat.default.pos == "text") { cat.pos.1 <- find.cat.pos(0.3, 0.5, cat.pos[1], cat.dist[1]) }
+		if (cat.default.pos == "outer") {
+			cat.pos.1 <- find.cat.pos(0.4, 0.5, cat.pos[1], cat.dist[1], max.circle.size);
+			cat.pos.2 <- find.cat.pos(0.6, 0.5, cat.pos[2], cat.dist[2], max.circle.size);
+			}
+		else if (cat.default.pos == "text") {
+			cat.pos.1 <- find.cat.pos(0.3, 0.5, cat.pos[1], cat.dist[1]);
+			cat.pos.2 <- find.cat.pos(0.7, 0.5, cat.pos[2], cat.dist[2]);
+			}
+		else {
+			stop("Invalid value for 'cat.default.pos', should be either 'outer' or 'text'");
+			}
+
 		tmp <- textGrob(
 			label = category[1],
 			x = cat.pos.1$x,
@@ -869,8 +945,6 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 			);
 		grob.list <- gList(grob.list, tmp);
 		
-		if (cat.default.pos == "outer") { cat.pos.2 <- find.cat.pos(0.6, 0.5, cat.pos[2], cat.dist[2], max.circle.size) }
-		if (cat.default.pos == "text") { cat.pos.2 <- find.cat.pos(0.7, 0.5, cat.pos[2], cat.dist[2]) }
 		tmp <- textGrob(
 			label = category[2],
 			x = cat.pos.2$x,
@@ -886,6 +960,7 @@ draw.pairwise.venn <- function(area1, area2, cross.area, category = rep("", 2),
 		grob.list <- gList(grob.list, tmp);
 	
 		}
+
 	grob.list <- adjust.venn(rotate.venn.degrees(grob.list, rotation.degree, rotation.centre[1], rotation.centre[2]), ...);
 	if (ind) { grid.draw(grob.list) }
 	return(grob.list);
