@@ -2,39 +2,39 @@
 draw.quad.venn <- function(area1, area2, area3, area4, n12, n13, n14, n23, n24, n34, n123, n124, n134, n234, n1234, category = rep("", 4), lwd = rep(2, 4), lty = rep("solid", 4), col = rep("black", 4), label.col = rep("black", 15), cex = rep(1, 15), fontface = rep("plain", 15), fontfamily = rep("serif", 15), cat.default.pos = "outer", cat.pos = c(-15, 15, 0, 0), cat.dist = c(0.22, 0.22, 0.11, 0.11), cat.col = rep("black", 4), cat.cex = rep(1, 4), cat.fontface = rep("plain", 4), cat.fontfamily = rep("serif", 4), cat.just = rep(list(c(0.5, 0.5)), 4), cat.prompts = FALSE, fill = NULL, alpha = rep(0.5, 4), rotation.degree = 0, rotation.centre = c(0.5, 0.5), ind = TRUE, ...) {
 #area1 > area2 > area3 > area4
 	# check parameter lengths
-	if (length(category) == 1) {cat = rep(category, 4)}
-	if (length(category) != 1 & length(category) != 4) { stop("Unexpected parameter length for 'category'.") }
-	if (length(lwd) == 1) {lwd = rep(lwd, 4)}
-	if (length(lwd) != 1 & length(lwd) != 4) { stop("Unexpected parameter length for 'lwd'.") }
-	if (length(lty) == 1) {lty = rep(lty, 4)}
-	if (length(lty) != 1 & length(lty) != 4) { stop("Unexpected parameter length for 'lty'.") }
-	if (length(col) == 1) {col = rep(col, 4)}
-	if (length(col) != 1 & length(col) != 4) { stop("Unexpected parameter length for 'col'.") }
-	if (length(label.col) == 1) {label.col = rep(label.col, 15)}
-	if (length(label.col) != 1 & length(label.col) != 15) { stop("Unexpected parameter length for 'label.col'.") }
-	if (length(cex) == 1) {cex = rep(cex, 15)}
-	if (length(cex) != 1 & length(cex) != 15) { stop("Unexpected parameter length for 'cex'.") }
-	if (length(fontface) == 1) {fontface = rep(fontface, 15)}
-	if (length(fontface) != 1 & length(fontface) != 15) { stop("Unexpected parameter length for 'fontface'.") }
-	if (length(fontfamily) == 1) {fontfamily = rep(fontfamily, 15)}
-	if (length(fontfamily) != 1 & length(fontfamily) != 15) { stop("Unexpected parameter length for 'fontfamily'.") }
-	if (length(fill) == 1) {fill = rep(fill, 4)}
-	if (length(fill) != 1 & length(fill) != 4 & length(fill) != 0) { stop("Unexpected parameter length for 'fill'.") }
-	if (length(alpha) == 1) {alpha = rep(alpha, 4)}
-	if (length(alpha) != 1 & length(alpha) != 4 & length(alpha) != 0) { stop("Unexpected parameter length for 'alpha'.") }
-	if (length(cat.pos) == 1) {cat.pos = rep(cat.pos, 4)}
-	if (length(cat.pos) != 1 & length(cat.pos) != 4) { stop("Unexpected parameter length for 'cat.pos'.") }
-	if (length(cat.dist) == 1) {cat.dist = rep(cat.dist, 4)}
-	if (length(cat.dist) != 1 & length(cat.dist) != 4) { stop("Unexpected parameter length for 'cat.dist'.") }
-	if (length(cat.col) == 1) {cat.col = rep(cat.col, 4)}
-	if (length(cat.col) != 1 & length(cat.col) != 4) { stop("Unexpected parameter length for 'cat.col'.") }
-	if (length(cat.cex) == 1) {cat.cex = rep(cat.cex, 4)}
-	if (length(cat.cex) != 1 & length(cat.cex) != 4) { stop("Unexpected parameter length for 'cat.cex'.") }
-	if (length(cat.fontface) == 1) {cat.fontface = rep(cat.fontface, 4)}
-	if (length(cat.fontface) != 1 & length(cat.fontface) != 4) { stop("Unexpected parameter length for 'cat.fontface'.") }
-	if (length(cat.fontfamily) == 1) {cat.fontfamily = rep(cat.fontfamily, 4)}
-	if (length(cat.fontfamily) != 1 & length(cat.fontfamily) != 4) { stop("Unexpected parameter length for 'cat.fontfamily'.") }
-	if (!(class(cat.just) == "list" & length(cat.just) == 4 & length(cat.just[[1]]) == 2 & length(cat.just[[2]]) == 2 & length(cat.just[[3]]) == 2 & length(cat.just[[4]]) == 2)) { stop("Unexpected parameter format for 'cat.just'.") }
+	if (length(category) == 1) {cat <- rep(category, 4)}
+	if (length(category) != 1 & length(category) != 4) { stop("Unexpected parameter length for 'category'") }
+	if (length(lwd) == 1) {lwd <- rep(lwd, 4)}
+	if (length(lwd) != 1 & length(lwd) != 4) { stop("Unexpected parameter length for 'lwd'") }
+	if (length(lty) == 1) {lty <- rep(lty, 4)}
+	if (length(lty) != 1 & length(lty) != 4) { stop("Unexpected parameter length for 'lty'") }
+	if (length(col) == 1) {col <- rep(col, 4)}
+	if (length(col) != 1 & length(col) != 4) { stop("Unexpected parameter length for 'col'") }
+	if (length(label.col) == 1) {label.col <- rep(label.col, 15)}
+	if (length(label.col) != 1 & length(label.col) != 15) { stop("Unexpected parameter length for 'label.col'") }
+	if (length(cex) == 1) {cex <- rep(cex, 15)}
+	if (length(cex) != 1 & length(cex) != 15) { stop("Unexpected parameter length for 'cex'") }
+	if (length(fontface) == 1) {fontface <- rep(fontface, 15)}
+	if (length(fontface) != 1 & length(fontface) != 15) { stop("Unexpected parameter length for 'fontface'") }
+	if (length(fontfamily) == 1) {fontfamily <- rep(fontfamily, 15)}
+	if (length(fontfamily) != 1 & length(fontfamily) != 15) { stop("Unexpected parameter length for 'fontfamily'") }
+	if (length(fill) == 1) {fill <- rep(fill, 4)}
+	if (length(fill) != 1 & length(fill) != 4 & length(fill) != 0) { stop("Unexpected parameter length for 'fill'") }
+	if (length(alpha) == 1) {alpha <- rep(alpha, 4)}
+	if (length(alpha) != 1 & length(alpha) != 4 & length(alpha) != 0) { stop("Unexpected parameter length for 'alpha'") }
+	if (length(cat.pos) == 1) {cat.pos <- rep(cat.pos, 4)}
+	if (length(cat.pos) != 1 & length(cat.pos) != 4) { stop("Unexpected parameter length for 'cat.pos'") }
+	if (length(cat.dist) == 1) {cat.dist <- rep(cat.dist, 4)}
+	if (length(cat.dist) != 1 & length(cat.dist) != 4) { stop("Unexpected parameter length for 'cat.dist'") }
+	if (length(cat.col) == 1) {cat.col <- rep(cat.col, 4)}
+	if (length(cat.col) != 1 & length(cat.col) != 4) { stop("Unexpected parameter length for 'cat.col'") }
+	if (length(cat.cex) == 1) {cat.cex <- rep(cat.cex, 4)}
+	if (length(cat.cex) != 1 & length(cat.cex) != 4) { stop("Unexpected parameter length for 'cat.cex'") }
+	if (length(cat.fontface) == 1) {cat.fontface <- rep(cat.fontface, 4)}
+	if (length(cat.fontface) != 1 & length(cat.fontface) != 4) { stop("Unexpected parameter length for 'cat.fontface'") }
+	if (length(cat.fontfamily) == 1) {cat.fontfamily <- rep(cat.fontfamily, 4)}
+	if (length(cat.fontfamily) != 1 & length(cat.fontfamily) != 4) { stop("Unexpected parameter length for 'cat.fontfamily'") }
+	if (!(class(cat.just) == "list" & length(cat.just) == 4 & length(cat.just[[1]]) == 2 & length(cat.just[[2]]) == 2 & length(cat.just[[3]]) == 2 & length(cat.just[[4]]) == 2)) { stop("Unexpected parameter format for 'cat.just'") }
 	cat.pos <- cat.pos + rotation.degree;
 	
 	# generate partial areas from given arguments
@@ -52,7 +52,7 @@ draw.quad.venn <- function(area1, area2, area3, area4, n12, n13, n14, n23, n24,
 	a9  <- area1 - a4 - a5 - a6 - a10 - a11 - a12 - a15;
 	a14 <- area2 - a6 - a7 - a8 - a11 - a12 - a13 - a15;
 	a1  <- area3 - a2 - a4 - a5 - a6 - a7 - a12 - a13;
-	a3  <- area4 - a2 - a5 - a6 - a7 - a8 - a10 - a11
+	a3  <- area4 - a2 - a5 - a6 - a7 - a8 - a10 - a11;
 		
 		
 	# check plausibility and 0 partial areas
@@ -428,7 +428,7 @@ draw.quad.venn <- function(area1, area2, area3, area4, n12, n13, n14, n23, n24,
 	
 	# adjust grob.list to fit and return grob.list
 	grob.list <- adjust.venn(rotate.venn.degrees(grob.list, rotation.degree, rotation.centre[1], rotation.centre[2]), ...);
-	if (ind) { grid.draw(grob.list) }
+	if (ind) { grid.draw(grob.list); }
 	return(grob.list);
 	
 	}
